import { FC, useCallback } from 'react'
import { Template } from '../../types/schema';
import { useObjectStateWrapper } from '../../hooks/useObjectState';
import { TEMPLATE_TYPES } from '../../constants/TemplateTypes';
import { SchemaEditAtom } from '../../recoil/atoms/schema';
import { useRecoilValue } from 'recoil';

interface IProps {
  templateKey: string;
  update: (arg0: string, arg1: Template) => void;
  template: Template
}

export const TemplateEditor: FC<IProps> = ({ templateKey, update, template }) => {
  const schema = useRecoilValue(SchemaEditAtom);
  const updateTemplate = useCallback((t: Template | ((arg: Template) => Template)) => {
    update(templateKey, typeof t === 'function' ? t(template) : t)
  }, [templateKey, update, template])

  const { bindProperty, bindPropertyCheck } = useObjectStateWrapper(template, updateTemplate)

  return (
    <li>
      <p className="font-bold">{templateKey}</p>
      <div className="flex gap-4">
        <label className="w-min">
          Type
          <input type="text" {...bindProperty('type')} list="type-editor-type-list" />
          <datalist id="type-editor-type-list">
            {Object.keys(TEMPLATE_TYPES).map(k => (
              <option className="capitalize" value={k}>{k}</option>
            ))}
            {Object.keys(schema.types).map(k => (
              <option className="capitalize" value={k}>{k}</option>
            ))}
          </datalist>
        </label>
        <label>
          <input type="checkbox" {...bindPropertyCheck('publishable')} />
          Can create publications
        </label>
      </div>
    </li>
  )
}